pub fn deserialize_graph<'de, NodeT: NodeEnum + Deserialize<'de>>(
input: GraphSerializer<NodeT>,
) -> (Context, Graph<NodeT>)Expand description
Helper function to deserialize a graph and construct a context for the graph
pub fn deserialize_graph<'de, NodeT: NodeEnum + Deserialize<'de>>(
input: GraphSerializer<NodeT>,
) -> (Context, Graph<NodeT>)Helper function to deserialize a graph and construct a context for the graph